import {
  createRouter,
  createWebHistory,
  createWebHashHistory,
} from "vue-router";
import routes from "./routes";
import LibForWeixin from "@/utils/LibForWeixin";
import { useUserStore, useAppStore } from "@/store";

const router = createRouter({
  // history: createWebHistory(import.meta.env.VITE_BASE),
  history: createWebHashHistory(),
  routes,
  scrollBehavior: () => ({
    el: "#app",
    top: 0,
    behavior: "smooth",
  }),
});
const whiteList = ["Login", "WxLogin"];
router.beforeEach(async (to, from, next) => {
  const appStore = useAppStore();
  if (!appStore.globalConfig && to.name !== "WxLogin") {
    let config = await appStore.getGlobalConfig();
    if (((config && !config?.taskTitle) || !config) && to.name !== "Login") {
      next({ name: "Login", replace: true });
      return;
    }
  }
  if (to.meta.jsApiList) {
    await LibForWeixin.initJSSDK(to.meta.jsApiList)
      .then(() => {
        console.log("config JS-SDK success");
      })
      .catch(() => {
        console.log("config JS-SDK fail");
      });
  }
  if (whiteList.includes(to.name)) {
    next();
    return;
  }
  const userStore = useUserStore();
  if (!userStore.loginInfo) {
    next({ name: "Login", replace: true });
  } else {
    next();
  }
});

router.afterEach((to) => {
  if (to.path !== "/favicon.icon") {
    document.title = to.meta.title ? to.meta.title : "";
  }
  window.scrollTo(0, 0);
});

export default router;
