import { defineStore } from "pinia";
import { getStuInfo, fetchOpenId, logout, wxUnbind, wxBind } from "@/api/user";
import router from "@/router/index";

const useUserStore = defineStore("user", {
  persist: {
    storage: localStorage,
    paths: ["loginInfo", "stuInfo", "openId"],
  },
  state: () => ({ loginInfo: null, stuInfo: null, openId: "" }),
  actions: {
    setState(data) {
      this.$patch(data);
    },
    setLoginInfo(data) {
      this.loginInfo = data;
    },
    requestStuInfo() {
      getStuInfo().then((res) => {
        this.stuInfo = res;
      });
    },
    setOpenId(openId) {
      this.openId = openId;
    },
    bindWx() {
      if (this.openId) {
        this.wxBind();
      }
    },
    async logout(bool) {
      if (!bool) {
        await wxUnbind().catch(() => {});
        logout().then(() => {
          router.replace("/login");
          this.resetUser();
        });
      } else {
        this.resetUser();
      }
    },
    resetUser() {
      this.$reset();
    },
  },
});

export default useUserStore;
