import { defineConfig, loadEnv } from "vite";
import vue from "@vitejs/plugin-vue";
import { resolve } from "path";
// import legacy from "@vitejs/plugin-legacy";
import AutoImport from "unplugin-auto-import/vite";
import Components from "unplugin-vue-components/vite";
import { VantResolver } from "@vant/auto-import-resolver";
import { viteMockServe } from "vite-plugin-mock";

export default defineConfig(({ mode }) => {
  const env = loadEnv(mode, process.cwd(), "");
  return {
    // 部署二级目录基础路径
    // base: env.VITE_BASE || "/",
    base: env.VITE_BASE,
    resolve: {
      alias: {
        "@": resolve(__dirname, "src"),
      },
    },
    server: {
      host: "0.0.0.0",
      port: 8200,
      strictPort: true,
      open: true,
      cors: true,
      proxy: {
        "/api": {
          // target: "http://192.168.10.41:8080",
          target: "http://apply-test.qmth.com.cn",
          changeOrigin: true,
          // rewrite: (path) => path.replace(new RegExp(`^${envConfig.proxy}`), ''),
        },
      },
    },
    build: {
      sourcemap: false,
      outDir: env.VITE_OUT_DIR,
      chunkSizeWarningLimit: 2000,
      reportCompressedSize: false,
    },
    plugins: [
      vue(),
      // legacy({
      //   targets: ["defaults", "not IE 11"],
      // }),
      viteMockServe(),
      AutoImport({
        resolvers: [VantResolver()],
      }),
      Components({
        resolvers: [VantResolver()],
      }),
    ],
  };
});
